
RELEASE_VERSION='0.0.376905154'
BUILD_DATE='Fri Sep 24 17:47:49 UTC 2021'
BUILD_MACHINE_INFO='Linux runner-mvj-ljo-project-28359933-concurrent-0cj4ww 5.4.129-62.227.amzn2.x86_64 #1 SMP Wed Jul 7 00:08:43 UTC 2021 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='1621323073'
GIT_COMMIT_SHA='2849695d02620675d90045db70ab5d7340fa9b1c'
GIT_BRANCH='main'
